==> zio-aws-amplifybackend_2.13-5.17.104.10-sources.jar: zio/aws/amplifybackend/model/GetBackendApiModelsResponse.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetBackendApiModelsResponse(
    models: Option[__string] = None,
    status: Option[zio.aws.amplifybackend.model.Status] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsResponse = {
    import GetBackendApiModelsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsResponse
      .builder()
      .optionallyWith(
        models.map(value => __string.unwrap(value): java.lang.String)
      )(_.models)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.GetBackendApiModelsResponse.ReadOnly =
    zio.aws.amplifybackend.model.GetBackendApiModelsResponse
      .wrap(buildAwsValue())
}
object GetBackendApiModelsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.GetBackendApiModelsResponse =
      zio.aws.amplifybackend.model.GetBackendApiModelsResponse(
        models.map(value => value),
        status.map(value => value)
      )
    def models: Option[__string]
    def status: Option[zio.aws.amplifybackend.model.Status]
    def getModels: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("models", models)
    def getStatus: ZIO[Any, AwsError, zio.aws.amplifybackend.model.Status] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsResponse
  ) extends zio.aws.amplifybackend.model.GetBackendApiModelsResponse.ReadOnly {
    override val models: Option[__string] = scala
      .Option(impl.models())
      .map(value => zio.aws.amplifybackend.model.primitives.__string(value))
    override val status: Option[zio.aws.amplifybackend.model.Status] = scala
      .Option(impl.status())
      .map(value => zio.aws.amplifybackend.model.Status.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsResponse
  ): zio.aws.amplifybackend.model.GetBackendApiModelsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-amplifybackend_2.13-5.17.145.1-sources.jar: zio/aws/amplifybackend/model/GetBackendApiModelsResponse.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetBackendApiModelsResponse(
    models: Option[__string] = None,
    status: Option[zio.aws.amplifybackend.model.Status] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsResponse = {
    import GetBackendApiModelsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsResponse
      .builder()
      .optionallyWith(models.map(value => value: java.lang.String))(_.models)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.GetBackendApiModelsResponse.ReadOnly =
    zio.aws.amplifybackend.model.GetBackendApiModelsResponse
      .wrap(buildAwsValue())
}
object GetBackendApiModelsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.GetBackendApiModelsResponse =
      zio.aws.amplifybackend.model.GetBackendApiModelsResponse(
        models.map(value => value),
        status.map(value => value)
      )
    def models: Option[__string]
    def status: Option[zio.aws.amplifybackend.model.Status]
    def getModels: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("models", models)
    def getStatus: ZIO[Any, AwsError, zio.aws.amplifybackend.model.Status] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsResponse
  ) extends zio.aws.amplifybackend.model.GetBackendApiModelsResponse.ReadOnly {
    override val models: Option[__string] =
      scala.Option(impl.models()).map(value => value: __string)
    override val status: Option[zio.aws.amplifybackend.model.Status] = scala
      .Option(impl.status())
      .map(value => zio.aws.amplifybackend.model.Status.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.GetBackendApiModelsResponse
  ): zio.aws.amplifybackend.model.GetBackendApiModelsResponse.ReadOnly =
    new Wrapper(impl)
}
